from HTMLParser import HTMLParser


class HTML2BBCode(HTMLParser):
    """
    HTML to BBCode converter

    >>> parser = HTML2BBCode()
    >>> parser.feed('<ul><li>one</li><li>two</li></ul>')
    u'[list][li]one[/li][li]two[/li][/list]'

    >>> parser.feed('<a href="http://google.com/">Google</a>')
    u'[url=http://google.com/]Google[/url]'

    >>> parser.feed('<img src="http://www.google.com/images/logo.png">')
    u'[img]http://www.google.com/images/logo.png[/img]'

    >>> parser.feed('<em>EM test</em>')
    u'[i]EM test[/i]'

    >>> parser.feed('<strong>Strong text</strong>')
    u'[b]Strong text[/b]'

    >>> parser.feed('<code>a = 10;</code>')
    u'[code]a = 10;[/code]'

    >>> parser.feed('<blockquote>Beautiful is better than ugly.</blockquote>')
    u'[quote]Beautiful is better than ugly.[/quote]'
    """
    def handle_starttag(self, tag, attrs):
        if tag == 'ul':
            self.data.append('[list]')
        elif tag == 'li':
            self.data.append('[li]')
        elif tag == 'a':
            attrs = dict(attrs)
            self.data.append('[url=%s]' % attrs.get('href'))
        elif tag == 'img':
            attrs = dict(attrs)
            self.data.append('[img]%s[/img]' % attrs.get('src'))
        elif tag == 'em':
            self.data.append('[i]')
        elif tag == 'strong':
            self.data.append('[b]')
        elif tag == 'code':
            self.data.append('[code]')
        elif tag == 'blockquote':
            self.data.append('[quote]')

    def handle_endtag(self, tag):
        if tag == 'ul':
            self.data.append('[/list]')
        elif tag == 'li':
            self.data.append('[/li]')
        elif tag == 'a':
            self.data.append('[/url]')
        elif tag == 'em':
            self.data.append('[/i]')
        elif tag == 'strong':
            self.data.append('[/b]')
        elif tag == 'code':
            self.data.append('[/code]')
        elif tag == 'blockquote':
            self.data.append('[/quote]')

    def handle_data(self, data):
        self.data.append(data)

    def feed(self, data):
        self.data = []
        HTMLParser.feed(self, data)
        return u''.join(self.data)

if __name__=='__main__':
    import doctest
    doctest.testmod()
